==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/de.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Couldn't add remote share" : "Entfernte Freigabe kann nicht hinzu gefügt werden",
    "Shared with you" : "Mit Dir geteilt",
    "Shared with others" : "Von Dir geteilt",
    "Shared by link" : "Geteilt über einen Link",
    "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Dir geteilt",
    "Files and folders others share with you will show up here" : "Mit Dir geteilte Dateien und Ordner anderer werden hier erscheinen",
    "Nothing shared yet" : "Noch nichts geteilt",
    "Files and folders you share will show up here" : "Von Dir geteilte Dateien und Ordner werden hier erscheinen",
    "No shared links" : "Keine geteilten Links",
    "Files and folders you share by link will show up here" : "Per Link freigegebene Dateien und Ordner werden hier erscheinen",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchtest Du die entfernte Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "You can upload into this folder" : "Du kannst in diesen Ordner hochladen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine OwnCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige OwnCloud-URL",
    "Shared by" : "Geteilt von ",
    "Sharing" : "Teilen",
    "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
    "A public shared file or folder was <strong>downloaded</strong>" : "Eine öffentliche geteilte Datei oder ein öffentlicher geteilter Ordner wurde <strong>heruntergeladen</strong>",
    "You received a new remote share %2$s from %1$s" : "Du hast eine neue Remotefreigabe %2$s von %1$s erhalten",
    "You received a new remote share from %s" : "Du hast eine neue Remotefreigabe von %s erhalten",
    "%1$s accepted remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s akzeptiert",
    "%1$s declined remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s abgelehnt",
    "%1$s unshared %2$s from you" : "%1$s hat die Freigabe von %2$s für Dich entfernt",
    "Public shared folder %1$s was downloaded" : "Der öffentliche geteilte Ordner %1$s wurde heruntergeladen",
    "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
    "You shared %1$s with %2$s" : "Du hast %1$s mit %2$s geteilt",
    "You shared %1$s with group %2$s" : "Du hast %1$s mit der Gruppe %2$s geteilt",
    "%2$s shared %1$s with %3$s" : "%2$s geteilt %1$s mit %3$s",
    "%2$s shared %1$s with group %3$s" : "%2$s geteilt %1$s mit Gruppe %3$s",
    "%2$s shared %1$s via link" : "%2$s geteilt %1$s via Link",
    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Dir geteilt",
    "You shared %1$s via link" : "Du hast %1$s über einen Link freigegeben",
    "Downloaded via public link" : "Runtergeladen mittels öffentlichen Link",
    "Shared with %2$s" : "Geteilt mit %2$s",
    "Shared with group %2$s" : "Geteilt mit Gruppe %2$s",
    "Shared with %3$s by %2$s" : "Geteilt mit %3$s von %2$s",
    "Shared with group %3$s by %2$s" : "Geteilt mit Gruppe %3$s von %2$s",
    "Shared via link by %2$s" : "Geteilt mittels Link von %2$s",
    "Shared by %2$s" : "Geteilt von %2$s",
    "Shared via public link" : "Geteilt mittels öffentlichen Link",
    "Shares" : "Freigaben",
    "You received %2$s as a remote share from %1$s" : "Du hast %2$s als Remotefreigabe von %1$s erhalten",
    "Accept" : "Ok",
    "Decline" : "Abgelehnt",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teile mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Teile mit mir über meine #ownCloud Federated-Cloud-ID",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Bitte überprüfe Dein Passwort und versuche es erneut.",
    "Password" : "Passwort",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Share time" : "Zeitpunkt der Freigabe",
    "Sorry, this link doesn’t seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the item was removed" : "Das Element wurde entfernt",
    "the link expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more info, please ask the person who sent this link." : "Um nähere Informationen zu erhalten, wende Dich bitte an die Person, die Dir diesen Link geschickt hat.",
    "Add to your ownCloud" : "Zu Deiner ownCloud hinzufügen",
    "Download" : "Herunterladen",
    "Download %s" : "Download %s",
    "Direct link" : "Direkter Link",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Deine Federated-Cloud-ID:",
    "Share it:" : "Zum Teilen:",
    "Add to your website" : "Zu deiner Webseite hinzufügen",
    "Share with me via ownCloud" : "Teile mit mir über ownCloud",
    "HTML Code:" : "HTML-Code:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/de.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Not allowed to create a federated share with the same user server" : "Nicht erlaubt eine föderierte Freigabe mit dem gleichen Benutzerserver zu erstellen",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Couldn't add remote share" : "Entfernte Freigabe kann nicht hinzu gefügt werden",
    "Shared with you" : "Mit Dir geteilt",
    "Shared with others" : "Von Dir geteilt",
    "Shared by link" : "Geteilt über einen Link",
    "Federated sharing" : "Federated-Sharing",
    "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Dir geteilt",
    "Files and folders others share with you will show up here" : "Mit Dir geteilte Dateien und Ordner anderer werden hier erscheinen",
    "Nothing shared yet" : "Noch nichts geteilt",
    "Files and folders you share will show up here" : "Von Dir geteilte Dateien und Ordner werden hier erscheinen",
    "No shared links" : "Keine geteilten Links",
    "Files and folders you share by link will show up here" : "Per Link freigegebene Dateien und Ordner werden hier erscheinen",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchtest Du die entfernte Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "You can upload into this folder" : "Du kannst in diesen Ordner hochladen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine OwnCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige OwnCloud-URL",
    "Shared by" : "Geteilt von ",
    "Sharing" : "Teilen",
    "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
    "A public shared file or folder was <strong>downloaded</strong>" : "Eine öffentliche geteilte Datei oder ein öffentlicher geteilter Ordner wurde <strong>heruntergeladen</strong>",
    "You received a new remote share %2$s from %1$s" : "Du hast eine neue Remotefreigabe %2$s von %1$s erhalten",
    "You received a new remote share from %s" : "Du hast eine neue Remotefreigabe von %s erhalten",
    "%1$s accepted remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s akzeptiert",
    "%1$s declined remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s abgelehnt",
    "%1$s unshared %2$s from you" : "%1$s hat die Freigabe von %2$s für Dich entfernt",
    "Public shared folder %1$s was downloaded" : "Der öffentliche geteilte Ordner %1$s wurde heruntergeladen",
    "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
    "You shared %1$s with %2$s" : "Du hast %1$s mit %2$s geteilt",
    "%2$s shared %1$s with %3$s" : "%2$s geteilt %1$s mit %3$s",
    "You removed the share of %2$s for %1$s" : "Sie haben die Freigabe von %2$s für %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s entfernt die Freigabe der %3$s für %1$s",
    "You shared %1$s with group %2$s" : "Du hast %1$s mit der Gruppe %2$s geteilt",
    "%2$s shared %1$s with group %3$s" : "%2$s geteilt %1$s mit Gruppe %3$s",
    "You removed the share of group %2$s for %1$s" : "Du hast der Gruppe von der Freigabe entfernt %2$s für %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s Freigabe der Gruppe entfernt %3$s für %1$s",
    "%2$s shared %1$s via link" : "%2$s geteilt %1$s via Link",
    "You shared %1$s via link" : "Du hast %1$s über einen Link freigegeben",
    "You removed the public link for %1$s" : "Du hast den öffentlichen Link für %1$s entfernt",
    "%2$s removed the public link for %1$s" : "%2$s entfernte den öffentlichen Link für %1$s",
    "Your public link for %1$s expired" : "Dein öffentlicher Link für %1$s ist abgelaufen",
    "The public link of %2$s for %1$s expired" : "Der öffentliche Link von %2$s für %1$s ist abgelaufen",
    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Dir geteilt",
    "%2$s removed the share for %1$s" : "%2$s entfernte die Freigabe für %1$s",
    "Downloaded via public link" : "Runtergeladen mittels öffentlichen Link",
    "Shared with %2$s" : "Geteilt mit %2$s",
    "Shared with %3$s by %2$s" : "Geteilt mit %3$s von %2$s",
    "Removed share for %2$s" : "Entfernte die Freigabe für %2$s",
    "%2$s removed share for %3$s" : "%2$s entfernte die Freigabe für %3$s",
    "Shared with group %2$s" : "Geteilt mit Gruppe %2$s",
    "Shared with group %3$s by %2$s" : "Geteilt mit Gruppe %3$s von %2$s",
    "Removed share of group %2$s" : "entfernte die Gruppe von der Freigabe %2$s   ",
    "%2$s removed share of group %3$s" : "%2$s entfernte die Gruppe von der Freigabe %3$s",
    "Shared via link by %2$s" : "Geteilt mittels Link von %2$s",
    "Shared via public link" : "Geteilt mittels öffentlichen Link",
    "Removed public link" : "entfernt öffentlichen Link",
    "%2$s removed public link" : "%2$s entfernte den öffentlichen Link",
    "Public link expired" : "öffentlicher Link ist abgelaufen",
    "Public link of %2$s expired" : "öffentlicher Link von %2$s ist abgelaufen",
    "Shared by %2$s" : "Geteilt von %2$s",
    "Shares" : "Freigaben",
    "You received \"/%2$s\" as a remote share from %1$s" : "Du empfängst \"/%2$s\" als Remote Freigabe von %1$s",
    "Accept" : "Ok",
    "Decline" : "Abgelehnt",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teile mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Teile mit mir über meine #ownCloud Federated-Cloud-ID",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Bitte überprüfe Dein Passwort und versuche es erneut.",
    "Password" : "Passwort",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Share time" : "Freigabezeitpunkt",
    "Sorry, this link doesn’t seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the item was removed" : "Das Element wurde entfernt",
    "the link expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more info, please ask the person who sent this link." : "Um nähere Informationen zu erhalten, wende Dich bitte an die Person, die Dir diesen Link geschickt hat.",
    "Add to your ownCloud" : "Zu Deiner ownCloud hinzufügen",
    "Download" : "Herunterladen",
    "Download %s" : "Download %s",
    "Direct link" : "Direkter Link",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Deine Federated-Cloud-ID:",
    "Share it:" : "Zum Teilen:",
    "Add to your website" : "Zu deiner Webseite hinzufügen",
    "Share with me via ownCloud" : "Teile mit mir über ownCloud",
    "HTML Code:" : "HTML-Code:"
},
"nplurals=2; plural=(n != 1);");
